@@ -17,5 +17,5 @@ Including another URLconf
 from django.urls import path, include
 
 urlpatterns = [
-       path(r'bi/', include('bi.urls')),
+       path('', include('bi.urls')),
 ]
